@@ -20,8 +20,8 @@ from time import sleep
 from tkinter.filedialog import askopenfilename
 from tkinter.messagebox import showwarning
 
-from stanfordkarel.karel_canvas import KarelCanvas
-from stanfordkarel.karel_definitions import DEFAULT_ICON, LIGHT_GREY, PAD_X, PAD_Y, KarelException
+from .karel_canvas import KarelCanvas
+from .karel_definitions import DEFAULT_ICON, LIGHT_GREY, PAD_X, PAD_Y, KarelException
 
 
 class StudentCode:
@@ -141,21 +141,17 @@ class KarelApplication(tk.Frame):
 
     def create_menubar(self):
         menubar = tk.Menu(self.master)
-
-        fileMenu = tk.Menu(menubar, tearoff=False)
-        menubar.add_cascade(label="File", menu=fileMenu)
-        fileMenu.add_command(
+        file_menu = tk.Menu(menubar, tearoff=False)
+        menubar.add_cascade(label="File", menu=file_menu)
+        file_menu.add_command(
             label="Exit", underline=1, command=self.master.quit, accelerator="Cmd+W"
         )
-
         iconmenu = tk.Menu(menubar, tearoff=0)
         menubar.add_cascade(label="Select Icon", menu=iconmenu)
-
         iconmenu.add_command(label="Karel", command=lambda: self.set_icon("karel"))
         iconmenu.add_command(label="Simple", command=lambda: self.set_icon("simple"))
 
         self.bind_all("<Command-w>", self.quit)
-
         self.master.config(menu=menubar)
 
     def quit(self, event):
